@@ -6,8 +6,8 @@ pub type UTC = DateTime<Utc>;
 #[tsync::tsync]
 #[derive(serde::Deserialize)]
 pub struct PaginationParams {
-    page: i64,
-    page_size: i64,
+    pub page: i64,
+    pub page_size: i64,
 }
 
 impl PaginationParams {
